@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use File::Find;
-use Image::Magick;
+use Image::Magick qw(QuantumDepth);
 use List::Util qw(max);
 
 use Module::Pluggable 
@@ -22,11 +22,11 @@ CSS::SpriteMaker - Combine several images into a single CSS sprite
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 
 =head1 SYNOPSIS
@@ -209,7 +209,7 @@ sub new {
         rc_override_classname => $opts{rc_override_classname},
 
         # the maximum color value
-        color_max => 2 ** Image::Magick::QuantumDepth - 1,
+        color_max => 2 ** QuantumDepth - 1,
     };
 
     return bless $self, $class;
